import type { APIRoute } from 'astro';
import { db } from '@db/database.ts';
import { API_SECRET } from 'astro:env/server';

export const GET: APIRoute = async ({ request }) => {
  if (API_SECRET && request.headers.get('authorization') !== `Basic ${API_SECRET}`) {
    return new Response(null, { status: 401 });
  }

  const teams = await db.getTeamsFull({});

  const response = [];
  for (const team of teams) {
    response.push({
      name: team.team.name,
      color: team.team.color,
      lastJoined: team.team.lastJoined ? new Date(team.team.lastJoined).getTime() : null,
      strikeWeight: team.strikeWeight ?? 0,
      memberOne: team.memberOne
        ? {
            uuid: team.memberOne.uuid,
            dead: team.memberOneDeath != null
          }
        : null,
      memberTwo: team.memberTwo
        ? {
            uuid: team.memberTwo.uuid,
            dead: team.memberTwoDeath != null
          }
        : null
    });
  }

  return new Response(JSON.stringify(response));
};
